Fix pi root deployment scripts

bs=1M speeds up deployment by 4x.

Also, default to 971 and make modify_rootfs.sh more robust to changes in
the image to modify

Change-Id: I2e1656a03ad2ec1c23b6d4d86759dcf0167659f6
diff --git a/y2020/vision/rootfs/target_configure.sh b/y2020/vision/rootfs/target_configure.sh
index 193f8b5..f761e84 100755
--- a/y2020/vision/rootfs/target_configure.sh
+++ b/y2020/vision/rootfs/target_configure.sh
@@ -83,5 +83,5 @@
 systemctl enable ssh.service
 systemctl enable frc971.service
 
-# Default us to pi-8971-1
-/root/bin/change_hostname.sh pi-8971-1
+# Default us to pi-971-1
+/root/bin/change_hostname.sh pi-971-1